require_relative 'player'
require_relative 'game_turn'
require_relative 'treasure_trove'
require 'csv'

module StudioGame
  class Game
    attr_accessor :title

    def initialize(title)
      @title = title
      @players = []
    end

    def save_high_scores(to_file = 'high_scores.txt')
      File.open(to_file, 'w') do |file|
        file.puts "#{title} High Scores:"

        @players.sort.each do |player|
          puts high_score_entry(player)
        end
      end
    end

    def high_score_entry(player)
      formatted_name = player.name.ljust(20, '.')
      puts "#{formatted_name} #{player.score}"
    end

    def load_players(from_file)
      CSV.foreach(from_file) do |row|
        player = Player.new(row[0], row[1].to_i)
        add_player(player)
      end
    end

    def total_points
      @players.reduce(0) { |sum, player| sum + player.points }
    end

    def add_player(a_player)
      @players.push(a_player)
    end

    def play(rounds)
      puts "There are #{@players.size} players in #{@title}: "
      puts @players.sort

      treasures = TreasureTrove::TREASURES
      puts "There are #{treasures.size} treasures to be found:"

      treasures.each do |treasure|
        puts "A #{treasure.name} is worth #{treasure.points} points"
      end

      1.upto(rounds) do |round|
        puts "\n Round #{round}:"

        @players.each do |player|
          GameTurn.take_turn(player)

          treasures = TreasureTrove.random
          puts player
        end
      end
    end

    def print_name_and_health(_player)
      puts "n\ #{@health}'s' stats:"
    end

    def print_stats
      strong, wimpy = @players.partition(&:strong?)

      puts "\nStrong:"
      puts strong.sort

      puts "\nWimpy:"
      puts wimpy.sort
      print_name_and_health(@player)

      puts "\n#{@title} High Scores:"
      @players.sort.each do |player|
        puts high_score_entry(player)

        @players.sort.each do |player|
          puts "\n#{player.name}'s point totals:"
          player.each_found_treasure do |treasure|
            puts "#{treasure.points} total #{treasure.name} points"
          end
          puts "#{player.points} grand total points"
        end
      end
    end
  end
end
